from pprint import pprint, pformat

from arichuvadi.valam import UYIRMEI_MAP_PATH
from arichuvadi import get_letters_coding

UYIRMEI = 'uyirmei'

IMAP = {}
MAP  = {}

def read_uyirmei_map():
    MAP[UYIRMEI] = {}
    IMAP[UYIRMEI]= {}
    with open(UYIRMEI_MAP_PATH) as f:
        for line in f.readlines()[1:]:
            letter, mei, uyir = line.strip().split('|')

            if len(uyir) > 0 and len(mei) > 0:
                MAP[UYIRMEI][letter] = mei + uyir #not fusing just concat
                IMAP[UYIRMEI][mei+uyir] = letter
            elif len(mei) > 0:
                MAP[UYIRMEI][letter] = mei
                IMAP[UYIRMEI][mei] = letter
            else:
                MAP[UYIRMEI][letter] = letter
                IMAP[UYIRMEI][letter] = letter


read_uyirmei_map()

def split_uyirmei(string, join_p=True):
    """
    தமிழ் -> த் அ ம் இ ழ்
    """

    letters = []
    for i in get_letters_coding(string.strip()):
        if i in MAP[ UYIRMEI ]:
            letters.extend(
                get_letters_coding( MAP[ UYIRMEI ][i] ))
        else:
            letters.append(i)

    if join_p:
        return ''.join(letters)
    return letters

def split_uyirmei2(string, join_p=True):
    """
    தமிழ் -> த ம் இ ழ்
    """
    letters = []
    inletters = get_letters_coding(string.strip())

    letters.append(inletters[0])
    for i in inletters[1:-1]:
        if i in MAP[ UYIRMEI ]:
            letters.extend(
                get_letters_coding( MAP[ UYIRMEI ][i] ))
        else:
            letters.append(i)

    letters.append(inletters[-1])

    if join_p:
        return ''.join(letters)
    return letters


def merge_uyirmei(instring):
    if len(instring) < 2:
        return ''.join(instring)

    string = list(instring[:])
    i = 0
    while i < len(string) - 1:
        couplet = string[i]+string[i+1]
        #print(couplet, string)
        if couplet in IMAP[ UYIRMEI ]:
            # print(''.join(string[:i]), '#',
            #       ''.join([IMAP[ UYIRMEI ][couplet]]), '#',
            #       ''.join(string[i+1:]))
            string = string[:i] + [(IMAP[ UYIRMEI ][couplet])] + string[i+2:]


        i += 1

    return ''.join(string)

if __name__ == '__main__':
    print(split_uyirmei('உயர் தனிச் செம் மொழி'))
    print(merge_uyirmei(list(split_uyirmei('உயர் தனிச் செம் மொழி'))))



import os

VER_ADAIVU = os.path.realpath(os.path.join(os.path.dirname(__file__), '..'))

THARAVU_ADAIVU = f'{VER_ADAIVU}/tharavu'

ADAIYALAMITTA_ARI_PATH = f'{THARAVU_ADAIVU}/adaiyalamitta-ari.txt'
ARI_PATH               = f'{THARAVU_ADAIVU}/ari.txt'
ARI_UNI_PATH           = f'{THARAVU_ADAIVU}/ari-uni.txt'
UYIRMEI_MAP_PATH       = f'{THARAVU_ADAIVU}/uyir-mei.csv'



import unittest
from arichuvadi import uyirmei

class TestSplitUyirmei(unittest.TestCase):
    def test_split_uyirmei(self):
        self.assertEqual('உய்அர் த்அன்இச் ச்எம் ம்ஒழ்இ',
                        uyirmei.split_uyirmei(
                            'உயர் தனிச் செம் மொழி'))

    def test_split_uyirmei2(self):
        self.assertEqual('உய்அர் த்அன்இச் ச்எம் ம்ஒழி',
                        uyirmei.split_uyirmei2(
                            'உயர் தனிச் செம் மொழி'))

    def test_merge_uyirmei(self):
        #import pdb; pdb.set_trace()
        self.assertEqual('உயர் தனிச் செம் மொழி',
                         uyirmei.merge_uyirmei(
                             list(uyirmei.split_uyirmei(
                                 'உயர் தனிச் செம் மொழி',
                                 join_p=False))))

if __name__ == '__main__':
    unittest.main()



import unittest


import arichuvadi
from arichuvadi import uyirmei


class TestArichuvadi(unittest.TestCase):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.saram = 'The Great உயர்தனிச்செம்மொழி தமிழ்!!!'
        self.expected_repr = "['T', 'h', 'e', ' ', 'G', 'r', 'e', 'a', 't', ' ', 'உ', 'ய', 'ர்', 'த', 'னி', 'ச்', 'செ', 'ம்', 'மொ', 'ழி', ' ', 'த', 'மி', 'ழ்', '!', '!', '!']"

    def test_get_letters_coding(self):
        #print(arichuvadi.get_letters_coding(self.saram))
        self.assertEqual(arichuvadi.get_letters_coding(self.saram),
                         ['T','h','e',' ','G','r','e','a','t',' ',\
                          'உ','ய','ர்','த','னி','ச்','செ','ம்','மொ','ழி',\
                          ' ','த','மி','ழ்','!','!','!'])

    def test_get_letters_glyph(self):
        #print(arichuvadi.get_letters_glyph(self.saram))
        self.assertEqual(arichuvadi.get_letters_glyph(self.saram),
                         ['T','h','e',' ','G','r','e','a','t',' ',\
                          'உ','ய','ர்','த','னி','ச்','செ','ம்','மொ','ழி',\
                          ' ','த','மி','ழ்','!','!','!'])

    def test_TamilStr_str(self):
        self.assertEqual(self.saram,
                        str(arichuvadi.TamilStr(self.saram)))

    def test_TamilStr_repr(self):
        repr_ = repr(arichuvadi.TamilStr(self.saram))
        assert len(repr_) == len(self.expected_repr), f'{len(repr_)} == {len(self.expected_repr)}'
        assert repr(arichuvadi.TamilStr(self.saram)) == self.expected_repr

if __name__ == '__main__':
    unittest.main()
